==> nextcloud-31.0.9.tgz: nextcloud/apps/comments/l10n/ast.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Comentesti",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Comentesti en: %1$s",
    "You commented on {file}" : "Comentesti en: {file}",
    "%1$s commented on %2$s" : "%1$s comentó en: %2$s",
    "{author} commented on {file}" : "{author} comentó en: {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> pa ficheros",
    "Files" : "Ficheros",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Mentáronte en «{file}», nun comentariu d'una cuenta que ta desaniciada",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mentóte nun comentariu de: «{file}»",
    "Files app plugin to add comments to files" : "Plugin de l'aplicación Ficheros p'amestar comentarios a los ficheros",
    "Edit comment" : "Editar el comentariu",
    "Delete comment" : "Desaniciar el comentariu",
    "Cancel edit" : "Anular la edición",
    "New comment" : "Comentariu nuevu",
    "Write a comment …" : "Escribi un comentariu…",
    "Post comment" : "Espublizar el comentariu",
    "@ for mentions, : for emoji, / for smart picker" : "@ pa les menciones, : pa los fustaxes, / pal selector intelixente",
    "Could not reload comments" : "Nun se pudieron recargar los comentarios",
    "Failed to mark comments as read" : "Nun se pudieron marcar los comentarios como lleíos",
    "Unable to load the comments list" : "Nun ye posible cargar la llista de comentarios",
    "No comments yet, start the conversation!" : "Nun hai comentarios, ¡anicia una conversación!",
    "No more messages" : "Nun hai más mensaxes",
    "Retry" : "Retentar",
    "_1 new comment_::_{unread} new comments_" : ["1 comentariu nuevu","{unread} comentarios nuevos"],
    "Comment" : "Comentariu",
    "An error occurred while trying to edit the comment" : "Prodúxose un error mentanto se tentaba d'editar el comentariu",
    "Comment deleted" : "Desanicióse'l comentariu",
    "An error occurred while trying to delete the comment" : "Prodúxose un error mentanto se tentaba de desaniciar el comentariu",
    "An error occurred while trying to create the comment" : "Prodúxose un error mentanto se tentaba de crear el comentariu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/comments/l10n/ast.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Comentesti",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Comentesti en: %1$s",
    "You commented on {file}" : "Comentesti en: {file}",
    "%1$s commented on %2$s" : "%1$s comentó en: %2$s",
    "{author} commented on {file}" : "{author} comentó en: {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> pa ficheros",
    "Files" : "Ficheros",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Mentáronte en «{file}», nun comentariu d'una cuenta que ta desaniciada",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mentóte nun comentariu de: «{file}»",
    "Files app plugin to add comments to files" : "Plugin de l'aplicación Ficheros p'amestar comentarios a los ficheros",
    "Edit comment" : "Editar el comentariu",
    "Delete comment" : "Desaniciar el comentariu",
    "Cancel edit" : "Anular la edición",
    "New comment" : "Comentariu nuevu",
    "Post comment" : "Espublizar el comentariu",
    "@ for mentions, : for emoji, / for smart picker" : "@ pa les menciones, : pa los fustaxes, / pal selector intelixente",
    "Could not reload comments" : "Nun se pudieron recargar los comentarios",
    "Failed to mark comments as read" : "Nun se pudieron marcar los comentarios como lleíos",
    "Unable to load the comments list" : "Nun ye posible cargar la llista de comentarios",
    "No comments yet, start the conversation!" : "Nun hai comentarios, ¡anicia una conversación!",
    "No more messages" : "Nun hai más mensaxes",
    "Retry" : "Retentar",
    "_1 new comment_::_{unread} new comments_" : ["1 comentariu nuevu","{unread} comentarios nuevos"],
    "Comment" : "Comentariu",
    "An error occurred while trying to edit the comment" : "Prodúxose un error mentanto se tentaba d'editar el comentariu",
    "Comment deleted" : "Desanicióse'l comentariu",
    "An error occurred while trying to delete the comment" : "Prodúxose un error mentanto se tentaba de desaniciar el comentariu",
    "An error occurred while trying to create the comment" : "Prodúxose un error mentanto se tentaba de crear el comentariu",
    "Write a comment …" : "Escribi un comentariu…"
},
"nplurals=2; plural=(n != 1);");
